@@ -1016,6 +1016,9 @@ def prepare_results(data_dict, dataset_list, results_data, run_date_key, sum_clo
                 if v not in data2:
                     data2[v] = ts_data1[v]
 
+            del ts_data2
+            del data1
+
         # Convert time back to UTC if necessary
         if (not freq_code in ['T', 'H', '1H']) and (not utc_offset == '0H'):
             data2['time'] = data2['time'].to_index().tz_localize(tz1).tz_convert('utc').tz_localize(None)
@@ -1033,6 +1036,9 @@ def prepare_results(data_dict, dataset_list, results_data, run_date_key, sum_clo
 
             data_dict[ds_id].append(new1)
 
+        del ts_data1
+        del data2
+
 
 
 
