@@ -576,7 +576,7 @@ def process_run_date(processing_code, dataset_list, remote, run_date=None, save_
     run_date : str, datetime, date, pd.Timestamp, or None
         The run_date to use for processing. If None, then the run_date will be generated.
     save_interval_hours : int
-        The frequency by which the datasets should have run dates saved as in Tethys. Essentially the question is, how frequently do you want to keep a record of the data changes? This value is in hours and the default is 2 weeks. This does not effect datasets with processing_code 3 as the run_date always stays the same.
+        The frequency by which the datasets should have run dates saved as in Tethys. Essentially the question is, how frequently do you want to keep a record of the data changes? This value is in hours and the default is 2 weeks. This does not effect datasets with processing_code 3 as the run_date always stays the same. A processing_code of 4 oe 5 always creates a new run_date.
 
     Returns
     -------
@@ -607,7 +607,9 @@ def process_run_date(processing_code, dataset_list, remote, run_date=None, save_
 
             if processing_code in [3]:
                 last_run_date_key = last_run_date.strftime('%Y%m%dT%H%M%SZ')
-            elif processing_code in [1, 2, 4, 5, 6]:
+            elif processing_code in [4, 5]:
+                last_run_date_key = run_date1.strftime('%Y%m%dT%H%M%SZ')
+            elif processing_code in [1, 2, 6]:
                 if last_run_date < (run_date1 - pd.DateOffset(hours=save_interval_hours) + pd.DateOffset(minutes=5)):
                     last_run_date_key = run_date1.strftime('%Y%m%dT%H%M%SZ')
                 else:
